@@ -4,5 +4,5 @@ from django.contrib.sites.models import Site
 
 @admin.register(Site)
 class SiteAdmin(admin.ModelAdmin):
-    list_display = ('domain', 'name')
-    search_fields = ('domain', 'name')
+    list_display = ("domain", "name")
+    search_fields = ("domain", "name")
